// // Tables
// table, th, td {
//    border: none;
// }

// table {
//   width:100%;
//   display: table;
// }

// thead {
//   border-bottom: 1px solid $table-border-color;
// }

// td, th{
//   padding: 15px 5px;
//   display: table-cell;
//   text-align: left;
//   vertical-align: middle;
//   border-radius: 2px;
// }