.tabs-target {
    display:none;
    &.active {
        display: block;
    }
}

.tabs {

    position: relative;
    overflow-x: auto;
    overflow-y: hidden;
    // height: 48px;
    // width: 100%;
    //background-color: $tabs-bg-color;
    margin: 0 auto;
    white-space: nowrap;
    margin-bottom: 15px;

    >ul {
        margin: 0 auto;
    }

    li {
        display: inline-block;
        text-align: center;
        line-height: 48px;
        height: 48px;
        padding: 0;
        margin: 0;
        text-transform: uppercase;

        a {
            @extend .tr-250;
            position: relative;
            color: rgba($tabs-text-color, .7);
            display: block;
            width: 100%;
            height: 100%;
            padding: 0 24px;
            font-size: 17px;
            text-overflow: ellipsis;
            overflow: hidden;
            transition: color .28s ease;

            &:hover,
            &.active {
                background-color: transparent;
                color: $tabs-text-color;
                &:after {
                    opacity: 1;
                }
            }

            &:after {
                @extend .tr-250;
                content: " ";
                position: absolute;
                left: 0px;
                right: 0px;
                bottom: 0px;
                border-bottom: 2px solid $primary-color;
                opacity: 0;
            }
            &.button {
                background-color: white;
            }

        }

        &.disabled a,
        &.disabled a:hover {
            color: rgba($tabs-text-color, .7);
            cursor: default;
        }
    }
    &.table {
        width: 100%;
        li {
            display: table-cell;
        }
    }
    &.wrap {
        overflow: visible;
        white-space: initial;
        
    }

    &.small {
        li {
            line-height: 34px;
            height: 34px;
            a {

                padding: 0 4px;
                font-size: 15px;
            }
        }
    }
    &.colored {
        li {
            a {
                background: #d4d2d2;
                &:hover,
                &.active {
                    background-color: white;
                }
            }
        }
    }
}