.panel {
    margin: 0px;
    margin-bottom: 25px;
    @include bs(0 2px 2px 0 rgba(0, 0, 0, 0.14), 0 1px 5px 0 rgba(0, 0, 0, 0.12), 0 3px 1px -2px rgba(0, 0, 0, 0.2));

    > h1 {
        padding: 10px 15px;
        margin: 0px 0px 0px 0px ;
        border-bottom: 1px solid #e8e8e8;
    }
    > h2 {
        padding: 10px 15px;
        margin: 0px 0px 0px 0px ;
        border-bottom: 1px solid #e8e8e8;
        a {
            font-size: 18px;
        }
    }
    &.panel-warning {
        background: lighten(orange, 40%);
        color: black;
    }
    &.panel-error {
        background: lighten($red-color, 45%);
        color: $red-color;
    }
}
    
.panel-body {
    padding: 25px;
}   
@media #{$medium-and-down} {
    .panel-body {
        padding: 15px;
    }
}