.brand {
    position: fixed;
    z-index: 10004;
    top: 7px;
    left: 7px;
    background: white;
    padding: 10px;

    @include bs(0 2px 2px 0 rgba(0,0,0,0.14), 0 1px 5px 0 rgba(0,0,0,0.12), 0 3px 1px -2px rgba(0,0,0,0.2));

    img {
        @include tr(all .3s);
        height: 50px;
        // animation: linear spinner 1s infinite;
        // transform-style: preserve-3d;

        // body.ready & {
        //     animation: none;
        //     transform: rotate3d(0);
        // }

    }
}

#brand-loading {
    position: fixed;
    top: 16px;
    left: 15px;
    z-index: 99999;
    background: white;
    width: 50px;
    height: 50px;
    min-height: 50px;
    visibility: visible;
    &:before, &:after {
        margin: -25px;
        width: 50px;
        height: 50px;
        animation: spin 0.8s infinite linear;
    }
    &:before {
        animation: spin 3s infinite linear;
        opacity: 0.7;
    }
    
    body.ready & {
        &:before, &:after {
            animation: spin 0.5s linear;
        }
        &:before {
            animation: spin 1s linear;
            opacity: 0.7;
        }
    }
}
