<div class="buttons-group clear">
    <div class="buttons fixed-buttons">
        <a data-modal-close class="button left">Annuler</a>
        <button data-tooltip="Enregistrer et fermer la fenêtre" type="submit" name="_save" value="1" class="button green right"><i class="fa fa-save"></i> {{ save_label|default:"Enregistrer" }}</button>
        <!-- <button data-tooltip="Enregistrer et continuer les modification"  type="submit" name="_save_and_continue" value="1" class="button green right"><i class="fa fa-save"></i> {{ save_label|default:"Enregistrer et continuer" }}</button> -->
        
    </div>
</div>

