<div class="{{ field.classes }}">
    {% load workon %}
    <!-- <div class="field-select"> -->
    {% include "workon/forms/fields/__label.html" %}
    {% if field|is_checkbox_select_multiple %}
        <div class="{{ classes.value }}">
            {% for choice in field %}
                  <p>
                    {{ choice.tag }}
                    <label for="{{ choice.auto_id }}">{{ choice.choice_label }}</label>
                  </p>
            {% endfor %}
        </div>

    {% else %}
        {{ field }}
    {% endif %}
    {% include 'workon/forms/fields/__help_and_errors.html' %}

</div>