<div class="{{ field.classes }} field-image _{{ classes.label }}">
    <div class="file-field">
        <div class="button">
            <span> {{ field.label }}</span>
            <div>
                {{ field }}
            </div>
        </div>
        <div class="file-path-wrapper">
            <input class="file-path validate" type="text" value="{% if field.value %}{{ field.value }}{% endif %}">
        </div>
        {% include "workon/forms/fields/__help_and_errors.html" %}
        {% if field.help_text %}
            <p class="{{ field.help_classes }}">{{ field.help_text|safe }}</p>
        {% endif %}
        {% if field.value %}
            {% if not field.field.required %}
            <div class="checkbox">
                <input type="checkbox" name="{{ field.checkbox_name }}" id="{{ field.checkbox_id }}" />
                <label style="top: 0;" for="{{ field.checkbox_id }}"  class="{{ form.required_css_class }}">
                    <span>Supprimer</span>
                </label>
            </div>
            {% endif %}
            <img class="responsive-img" src="{{ field.value.url }}" alt=""  />
        {% endif %}
    </div>
</div>