<div class="{{ field.classes }}">
    {{ field }}
    {% if field.auto_id and field.label %}
        <label class="{{ field.label_classes }} {% if field.field.required %}{{ form.required_css_class }}{% endif %}" for="{{ field.auto_id }}">{{ field.label }}</label>
    {% endif %}
    {% for error in field.errors %}
        <p class="{{ field.error_classes }}">{{ error }}</p>
    {% endfor %}
    {% if field.help_text %}
        <p class="{{ field.help_classes }}">{{ field.help_text|safe }}</p>
    {% endif %}
    <script>
        (function ($, input)
        {
            input = $('#id_{{ field.name }}');
            input.on('change', function()
            {
                var embed = $.fn.strToEmbed($(this).val());
            })

        }(jQuery));
    </script>
</div>