.pagination {

    li {
        display: inline-block;
        border-radius: 2px;
        text-align: center;
        vertical-align: top;
        height: 30px;

        a {
            color: #444;
            display: inline-block;
            font-size: 1.2rem;
            padding: 0 10px;
            line-height: 30px;
        }

        &.active a { color: #fff; }

        &.active { background-color: $primary-color; }

        &.disabled a {
            cursor: default;
            color: #999;
        }

        i {
            font-size: 2rem;
        }
        &.navigation {
            a {
                padding: 0 0px;
            }
        }
    }

    .pagination-total {
        font-size: 13px;
        line-height: 33px;
    }

    li.pages ul li {
        display: inline-block;
        float: none;
    }
}

@media #{$medium-and-down} {
    .pagination {        
        width: 100%;

        li.prev,
        li.next {
            width: 10%;
        }

        li.pages {
            width: 80%;
            overflow: hidden;
            white-space: nowrap;
        }
    }
}