.field {
    margin-top: 0px;
    margin-bottom: 15px;
    &.field-error {
        .field-label { 
            color: $error-color;
        }
        input, textarea, select, .select2-selection {
            border-color: $error-color;

        }
    }
    &.field-highlight {
        font-weight: bold;
        // display: inline-block;
    }
}

p.field-error {
    margin-top: 3px;
    font-style: italic;
    font-size: 75%;
    color: $error-color;
}
    
.field-label { 
    color: #9e9e9e;
    bottom: -10px;
    font-size: 1rem;
    position: relative;
    cursor: text;
    text-align: initial;
    display: block;
}
.field-help {
    font-style: italic;
    font-size: 75%;
    margin-bottom: 5px;
    // display: inline-block;
}

