<div class="{{ field.classes }} field-widget-checkbox">
    <div class="{{ classes.single_value }}">
        <div class="checkbox">          
            {{ field }} 
            {% include "workon/forms/fields/__label.html" %} 
            {% include "workon/forms/fields/__help_and_errors.html" %}
        </div>
    </div>
</div>