<div class="checkbox">
    {% include "forms/widgets/input.html" %}
    {% if wrap_label %}
    <label{% if widget.attrs.id %} for="{{ widget.attrs.id }}"{% endif %}>{% endif %}
    {% if wrap_label %} 
        <span>{{ widget.label }}</span>
    </label>
    {% endif %}
</label{%>