.field {
    margin-top: 0px;
    margin-bottom: 15px;
    position: relative;
    &.field-error {
        .field-label { 
            color: $error-color;
        }
        input, textarea, select, .select2-selection {
            border-color: $error-color;
        }
    }
    &.field-highlight {
        font-weight: bold;
        // display: inline-block;
    }
    input, textarea, select, .select2-selection {
        background-color: white !important;
        padding-left: 5px;
        padding-right: 5px;
    }
    &.with-icon {
        input, textarea {
            padding-left: 35px;
        }
        .icon {            
            @include tr(all 0.1s ease-out);
            position: absolute;
            float: left;
            top: 50%;
            @include tf(translateY(-50%));
            left: 5px;
            z-index: 1;
            color: $text-color;
        }
    }
    .tree {
        margin-top: 0px;
        z-index: 0;
    }

}

span.field-error,
p.field-error {
    margin-top: 3px;
    font-style: italic;
    font-size: 75%;
    color: $error-color;
}
    
.field-label { 
    color: #9e9e9e;
    bottom: -10px;
    font-size: 1rem;
    position: relative;
    cursor: text;
    text-align: initial;
    display: block;    
    z-index: 1;
    &.solo {
        bottom: 0px;
    }
}

.field-label + textarea {
    margin-top: 15px;
}
.field-help {
    font-style: italic;
    font-size: 75%;
    margin-bottom: 5px;
    // display: inline-block;
}

@import 'fields/*.scss';
